@@ -70,6 +70,11 @@ def main():
         action="store_true",
         help=f"Enable DEBUG level logging.",
     )
+    group.add_argument(
+        "--no-respawn-on-update",
+        action="store_true",
+        help=f"Disable auto respawn on dl update finish.",
+    )
 
     group = parser.add_argument_group("InfServer").add_mutually_exclusive_group()
     group.add_argument("--start", action="store_true", help=f"Start InfServer.")
@@ -128,14 +133,20 @@ def main():
             success()
             print(f"InfServer status: {status}\n")
         elif args.version:
-
             print(VERSION)
         elif args.engine_version:
-
             print(f"{server.version()}")
         elif args.dl_update:
             print(" * Update data", end="")
-            server.update_data(dldata=args.dl_update, db_name=args.db_name)
+
+            if args.no_respawn_on_update:
+                respawn_dp = False
+            else:
+                respawn_dp = True
+
+            server.update_data(
+                dldata=args.dl_update, db_name=args.db_name, respawn_dp=respawn_dp
+            )
             success()
         elif args.dl_delete:
             print(" * Delete data", end="")
