@@ -351,9 +351,9 @@ class InfEngineServer:
                 self._logger.error(f"Can't stop InfEngine server: {res}")
                 return
 
-        sleep(10)
-
-        self._logger.info("InfEngine workers have respawned.")
+        # sleep(10)
+        #
+        # self._logger.info("InfEngine workers have respawned.")
 
     def status(self):
         """ Check InfEngine server status. """
@@ -369,6 +369,7 @@ class InfEngineServer:
         dlsources: str = None,
         strict: bool = False,
         db_name: str = "dldata",
+        respawn_dp: bool = True,
     ):
         """ Update DL data. """
 
@@ -415,7 +416,9 @@ class InfEngineServer:
         engine.install(dldata, dlsources, db_name=db_name)
 
         shutil.rmtree(temp_dir_path)
-        self.respawn()
+
+        if respawn_dp:
+            self.respawn()
 
     def delete_dl(self, database_name):
         """ Delete DL databases. """
